@@ -278,8 +278,7 @@ comorbid = {cat("Call: ")
    
 set.cor= { cat("Call: ")
               print(x$Call)
-            if(x$raw) {cat("\nMultiple Regression from raw data \n")} else {
-            cat("\nMultiple Regression from matrix input \n")}
+            cat("\nMultiple Regression from matrix input \n")
            cat("\nBeta weights \n")
            print(round(x$beta,digits))
            cat("\nMultiple R \n") 
@@ -317,10 +316,10 @@ set.cor= { cat("Call: ")
             cat("\n Cohen's Set Correlation R2 = ",round(x$Rset,digits=digits))
             #print(x$Rset,digits=digits)
            if(!is.null(x$Rset.shrunk)){ cat("\n Shrunken Set Correlation R2 = ",round(x$Rset.shrunk,digits=digits))
-          
+           # print(x$Rset.shrunk,digits=digits)
             cat("\n F and df of Cohen's Set Correlation ",round(c(x$Rset.F,x$Rsetu,x$Rsetv), digits=digits))}
            }
-
+          #  print(x$T,digits=digits)
 
    },
    
